Index: wp-content/themes/twentyten/author.php
===================================================================
--- wp-content/themes/twentyten/author.php	(revision 13398)
+++ wp-content/themes/twentyten/author.php	(working copy)
@@ -21,7 +21,7 @@
 
 <?php rewind_posts(); ?>
 
-<?php get_generic_template( 'loop', 'author' ); ?>
+<?php get_specific_template( 'loop', 'author' ); ?>
 
 			</div><!-- #content -->
 		</div><!-- #container -->
Index: wp-content/themes/twentyten/search.php
===================================================================
--- wp-content/themes/twentyten/search.php	(revision 13398)
+++ wp-content/themes/twentyten/search.php	(working copy)
@@ -5,7 +5,7 @@
 
 <?php if ( have_posts() ) : ?>
 				<h1 class="page-title"><?php _e( 'Search Results for: ', 'twentyten' ); ?><span><?php the_search_query(); ?></span></h1>
-	<?php get_generic_template( 'loop', 'search' ); ?>
+	<?php get_specific_template( 'loop', 'search' ); ?>
 <?php else : ?>
 				<div id="post-0" class="post no-results not-found">
 					<h2 class="entry-title"><?php _e( 'Nothing Found', 'twentyten' ); ?></h2>
Index: wp-content/themes/twentyten/index.php
===================================================================
--- wp-content/themes/twentyten/index.php	(revision 13398)
+++ wp-content/themes/twentyten/index.php	(working copy)
@@ -4,7 +4,7 @@
 			<div id="content">
 
     <?php if ( have_posts() ) : 
-		get_generic_template( 'loop', 'index' );
+		get_specific_template( 'loop', 'index' );
     else : ?>
 		<h2><?php _e( 'Not Found', 'twentyten' ); ?></h2>
 		<div class="entry-content">
Index: wp-content/themes/twentyten/tag.php
===================================================================
--- wp-content/themes/twentyten/tag.php	(revision 13398)
+++ wp-content/themes/twentyten/tag.php	(working copy)
@@ -9,7 +9,7 @@
 
 <?php rewind_posts(); ?>
 
-<?php get_generic_template( 'loop', 'tag' ); ?>
+<?php get_specific_template( 'loop', 'tag' ); ?>
 
 			</div><!-- #content -->
 		</div><!-- #container -->
Index: wp-content/themes/twentyten/category.php
===================================================================
--- wp-content/themes/twentyten/category.php	(revision 13398)
+++ wp-content/themes/twentyten/category.php	(working copy)
@@ -6,7 +6,7 @@
 				<h1 class="page-title"><?php _e( 'Category Archives:', 'twentyten' ); ?> <span><?php single_cat_title(); ?></span></span></h1>
 				<?php $categorydesc = category_description(); if ( !empty($categorydesc) ) echo apply_filters( 'archive_meta', '<div class="archive-meta">' . $categorydesc . '</div>' ); ?>
 
-<?php get_generic_template( 'loop', 'category' ); ?>
+<?php get_specific_template( 'loop', 'category' ); ?>
 
 			</div><!-- #content -->
 		</div><!-- #container -->
Index: wp-content/themes/twentyten/archive.php
===================================================================
--- wp-content/themes/twentyten/archive.php	(revision 13398)
+++ wp-content/themes/twentyten/archive.php	(working copy)
@@ -17,7 +17,7 @@
 
 <?php rewind_posts(); ?>
 
-<?php get_generic_template( 'loop', 'archive' ); ?>
+<?php get_specific_template( 'loop', 'archive' ); ?>
 
 			</div><!-- #content -->
 		</div><!-- #container -->


Index: wp-includes/general-template.php
===================================================================
--- wp-includes/general-template.php	(revision 13398)
+++ wp-includes/general-template.php	(working copy)
@@ -94,7 +94,7 @@
 }
 
 /**
  * Load a generic template.
  *
  * Includes the named template for a theme or if a name is specified then a
  * specialised template will be included. If the theme contains no {slug}.php file
@@ -105,13 +105,13 @@
  *
  * @uses locate_template()
  * @since 3.0.0
- * @uses do_action() Calls 'get_generic_template_{$slug}' action.
+ * @uses do_action() Calls 'get_specific_template_{$slug}' action.
  *
  * @param string $slug The slug name for the generic template.
  * @param string $name The name of the specialised template.
  */
-function get_generic_template( $slug, $name = null ) {
-	do_action( "get_generic_template_{$slug}", $name );
+function get_specific_template( $slug, $name = null ) {
+	do_action( "get_specific_template_{$slug}", $name );
 
 	$templates = array();
 	if ( isset($name) )
@@ -94,7 +94,7 @@
 
 /**
- * Load a generic template.
+ * Load a specific template.
  *
  * Includes the named template for a theme or if a name is specified then a